@@ -19,11 +19,25 @@
  * Daniel.Veillard@w3.org
  */
 
-#include <ctype.h>
-#include <string.h>
-#include <stdio.h>
-#include "encoding.h"
+#ifndef WIN32
+#include "config.h"
+#endif
 
+#include <stdio.h>
+#include <string.h>
+
+#ifdef HAVE_CTYPE_H
+#include <ctype.h>
+#endif
+#include "encoding.h"
+#ifdef HAVE_UNICODE_H
+#include <unicode.h>
+#endif
+#include "xmlmemory.h"
+
+#ifdef HAVE_UNICODE_H
+
+#else /* ! HAVE_UNICODE_H */
 /*
  * From rfc2044: encoding of the Unicode values on UTF-8:
  *
@@ -79,7 +93,8 @@ isolat1ToUTF8(unsigned char* out, int outlen, unsigned char* in, int inlen)
  *
  * Take a block of UTF-8 chars in and try to convert it to an ISO Latin 1
  * block of chars out.
- * TODO: need a fallback mechanism ...
+ * TODO: UTF8Toisolat1 need a fallback mechanism ...
+ *
  * Returns the number of byte written, or -1 by lack of space, or -2
  *     if the transcoding failed.
  */
@@ -163,7 +178,8 @@ UTF16ToUTF8(unsigned char* out, int outlen, unsigned short* in, int inlen)
  *
  * Take a block of UTF-8 chars in and try to convert it to an UTF-16
  * block of chars out.
- * TODO: need a fallback mechanism ...
+ * TODO: UTF8ToUTF16 need a fallback mechanism ...
+ *
  * Returns the number of byte written, or -1 by lack of space, or -2
  *     if the transcoding failed.
  */
@@ -206,6 +222,7 @@ UTF8ToUTF16(unsigned short* out, int outlen, unsigned char* in, int inlen)
     return out-outstart;
 }
 
+#endif /* ! HAVE_UNICODE_H */
 
 /**
  * xmlDetectCharEncoding:
@@ -361,7 +378,7 @@ xmlNewCharEncodingHandler(const char *name, xmlCharEncodingInputFunc input,
 	if (upper[i] == 0) break;
     }
     upper[i] = 0;
-    up = strdup(upper);
+    up = xmlMemStrdup(upper);
     if (up == NULL) {
         fprintf(stderr, "xmlNewCharEncodingHandler : out of memory !\n");
 	return(NULL);
@@ -371,7 +388,7 @@ xmlNewCharEncodingHandler(const char *name, xmlCharEncodingInputFunc input,
      * allocate and fill-up an handler block.
      */
     handler = (xmlCharEncodingHandlerPtr)
-              malloc(sizeof(xmlCharEncodingHandler));
+              xmlMalloc(sizeof(xmlCharEncodingHandler));
     if (handler == NULL) {
         fprintf(stderr, "xmlNewCharEncodingHandler : out of memory !\n");
 	return(NULL);
@@ -400,15 +417,18 @@ xmlInitCharEncodingHandlers(void) {
     if (handlers != NULL) return;
 
     handlers = (xmlCharEncodingHandlerPtr *)
-        malloc(MAX_ENCODING_HANDLERS * sizeof(xmlCharEncodingHandlerPtr));
+        xmlMalloc(MAX_ENCODING_HANDLERS * sizeof(xmlCharEncodingHandlerPtr));
 
     if (handlers == NULL) {
         fprintf(stderr, "xmlInitCharEncodingHandlers : out of memory !\n");
 	return;
     }
     xmlNewCharEncodingHandler("UTF-8", NULL, NULL);
-    xmlNewCharEncodingHandler("UTF-16", UTF16ToUTF8, UTF8ToUTF16);
+#ifdef HAVE_UNICODE_H
+#else
+    /* xmlNewCharEncodingHandler("UTF-16", UTF16ToUTF8, UTF8ToUTF16); */
     xmlNewCharEncodingHandler("ISO-8859-1", isolat1ToUTF8, UTF8Toisolat1);
+#endif
 }
 
 /**
@@ -445,6 +465,7 @@ xmlRegisterCharEncodingHandler(xmlCharEncodingHandlerPtr handler) {
 xmlCharEncodingHandlerPtr
 xmlGetCharEncodingHandler(xmlCharEncoding enc) {
     if (handlers == NULL) xmlInitCharEncodingHandlers();
+    /* TODO xmlGetCharEncodingHandler !!!!!!! */
     return(NULL);
 }
 
