@@ -41,7 +41,7 @@ static int copy = 0;
 
 /*
  * Note: this is perfectly clean HTML, i.e. not a useful test.
-static CHAR buffer[] = 
+static xmlChar buffer[] = 
 "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\"\n\
                       \"http://www.w3.org/TR/REC-html40/loose.dtd\">\n\
 <html>\n\
@@ -96,7 +96,7 @@ void parseAndPrintFile(char *filename) {
     xmlFreeDoc(doc);
 }
 
-void parseAndPrintBuffer(CHAR *buf) {
+void parseAndPrintBuffer(xmlChar *buf) {
     htmlDocPtr doc, tmp;
 
     /*
